
/*  @(#)output.c 1.6 95/08/25
 *
 *  Various routines associated with the output popup.
 *
 *  Copyright (c) Rich Burridge.    All rights reserved.
 *
 *  Permission is given to distribute these sources, as long as the
 *  copyright messages are not removed, and no monies are exchanged.
 *
 *  No responsibility is taken for any errors or inaccuracies inherent
 *  either to the comments or the code of this program, but if
 *  reported to me then an attempt will be made to fix them.
 */

#include "mptool.h"

Widget opopup ;            /* Output options popup. */
Widget *owarr ;


void
do_output_apply(void)
{
  set_int_opt_val(O_LLEN, get_int_value(F_OUTPUT,  WI_LINE_LENGTH)) ;
  set_int_opt_val(O_PLEN, get_int_value(F_OUTPUT,  WI_PAGE_LENGTH)) ;
  set_str_opt_val(O_PR_NAME, get_str_value(F_OUTPUT,  WI_PRINTER_NAME)) ;
}
 
 
void
do_output_dismiss(void)
{
  XtUnmapWidget(opopup) ;
  XtUnmanageChild(opopup) ;
}
 
 
void
do_output_reset(void)
{
  set_int_value(F_OUTPUT,  WI_LINE_LENGTH,  int_opt_val(O_LLEN)) ;
  set_int_value(F_OUTPUT,  WI_PAGE_LENGTH,  int_opt_val(O_PLEN)) ;
  set_str_value(F_OUTPUT,  WI_PRINTER_NAME, str_opt_val(O_PR_NAME)) ;
}


/*  Do corrections like in 'adjust_paper_size' (../common/option.c)
 *
 *  Save values with 'set_int_opt_val' and - if output widget is realised -
 *  update the displayed values. This is the same action (apart from the
 *  printername) as done with the apply-button. I hesitated to set the
 *  variables plen and llen via 'set_int_opt_val' since these seem to be
 *  used as defaults.
 *  But if the output widget is not shown, incorrect values would be used.
 *
 *  Unlike 'adjust_paper_size', this function will not honour settings
 *  for the parameters 'O_LLEN' and 'O_PLEN' from the commandline or a
 *  resource file.
 */

void
do_output_update(void)
{
  enum paper_type psize ;
  int linelen, pagelen, land ;

       if (get_bool_value(F_MAIN, WI_PAPER_SIZE_A4)) psize = P_A4 ;
  else if (get_bool_value(F_MAIN, WI_PAPER_SIZE_US)) psize = P_US ;
  else                                               psize = P_NONE ;

       if (get_bool_value(F_MAIN, WI_OUTPUT_LAND)) land = 1 ;
  else if (get_bool_value(F_MAIN, WI_OUTPUT_PORT)) land = 0 ;
  else                                             land = -1 ;

  if (land == -1) return ;     /* Organizer formats - do nothing. */

  switch (psize)
  {
    case P_US : linelen = (land) ? 80 : 80 ;
                pagelen = (land) ? 68 : 72 ;
                break ;
    case P_A4 : linelen = (land) ? 90 : 80 ;
                pagelen = (land) ? 66 : 78 ;
                break ;

/* Not nice: this uses the system default and ignores resources and
 * command line options. Maybe should do nothing at all ...
 */ 

      default : linelen = LINELENGTH ;
                pagelen = PAGELENGTH ;
                break ;
   }

/* Now set correct values as new default (?) values. */

  set_int_opt_val(O_LLEN, linelen) ;
  set_int_opt_val(O_PLEN, pagelen) ;

  if (!opopup)
    return ;
  else
    {  

/* Show new values in output widget. */

       set_int_value(F_OUTPUT,  WI_LINE_LENGTH,  linelen) ;
       set_int_value(F_OUTPUT,  WI_PAGE_LENGTH,  pagelen) ;
    }  
}


void
do_show_output(void)
{
  if (!opopup)
    {
      opopup = tu_output_frame_widget("output", warr[WI_MAIN_FRAME],
                                      &owarr) ;
      add_delete_callback(opopup) ;
      add_help(owarr[WI_OUTPUT_FORM],        wi_output_frame_help) ;
      add_help(owarr[WI_OUTPUT_APPLY],       wi_output_apply_help) ;
      add_help(owarr[WI_OUTPUT_RESET],       wi_output_reset_help) ;
      add_help(owarr[WI_OUTPUT_DISMISS],     wi_output_dismiss_help) ;
      add_help(owarr[WI_LINE_LENGTH_LABEL],  wi_line_length_help) ;
      add_help(owarr[WI_LINE_LENGTH],        wi_line_length_help) ;
      add_help(owarr[WI_PAGE_LENGTH_LABEL],  wi_page_length_help) ;
      add_help(owarr[WI_PAGE_LENGTH],        wi_page_length_help) ;
      add_help(owarr[WI_PRINTER_NAME_LABEL], wi_printer_name_help) ;
      add_help(owarr[WI_PRINTER_NAME],       wi_printer_name_help) ;
      do_output_reset() ;
    } 
  show_popup(opopup) ;
}


void
Output(void)
{
  owarr = NULL ;           /* No widgets defined initially. */
  opopup = NULL ;          /* No output popup window initially. */
}
